# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from ctddocumentation.models.object import Object


class RangerSystemCheckResponse(object):

    """Implementation of the 'RangerSystemCheckResponse' model.

    TODO: type model description here.

    Attributes:
        data (object): TODO: type description here.
        success (bool): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "data": 'data',
        "success": 'success'
    }

    def __init__(self,
                 data=None,
                 success=None):
        """Constructor for the RangerSystemCheckResponse class"""

        # Initialize members of the class
        self.data = data 
        self.success = success 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary

        data = Object.from_dictionary(dictionary.get('data')) if dictionary.get('data') else None
        success = dictionary.get("success") if "success" in dictionary.keys() else None
        # Return an object of this model
        return cls(data,
                   success)
