# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Format1Enum(object):

    """Implementation of the 'format1' enum.

    Specifies the type of response (list of fields) returned by the query. 
    If not provided, all asset's properties will return and could affect
    performance.

    Attributes:
        ASSET_LIST: TODO: type description here.
        INSIGHT_ASSETS: TODO: type description here.
        RIDS: TODO: type description here.

    """

    ASSET_LIST = 'asset_list'

    INSIGHT_ASSETS = 'insight_assets'

    RIDS = 'rids'
