# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Sort1Enum(object):

    """Implementation of the 'sort1' enum.

    TODO: type enum description here.

    Attributes:
        NAME: TODO: type description here.
        ENUM_NAME: TODO: type description here.
        STATUS: TODO: type description here.
        ENUM_STATUS: TODO: type description here.
        ENABLED: TODO: type description here.
        ENUM_ENABLED: TODO: type description here.
        INTERVAL: TODO: type description here.
        ENUM_INTERVAL: TODO: type description here.
        START_TIME: TODO: type description here.
        ENUM_START_TIME: TODO: type description here.
        END_TIME: TODO: type description here.
        ENUM_END_TIME: TODO: type description here.
        ALLOWED_RUN_TIME_START: TODO: type description here.
        ENUM_ALLOWED_RUN_TIME_START: TODO: type description here.
        ALLOWED_RUN_TIME_END: TODO: type description here.
        ENUM_ALLOWED_RUN_TIME_END: TODO: type description here.
        LAST_RUN_RESULTS: TODO: type description here.
        ENUM_LAST_RUN_RESULTS: TODO: type description here.

    """

    NAME = 'name'

    ENUM_NAME = '-name'

    STATUS = 'status'

    ENUM_STATUS = '-status'

    ENABLED = 'enabled'

    ENUM_ENABLED = '-enabled'

    INTERVAL = 'interval'

    ENUM_INTERVAL = '-interval'

    START_TIME = 'start_time'

    ENUM_START_TIME = '-start_time'

    END_TIME = 'end_time'

    ENUM_END_TIME = '-end_time'

    ALLOWED_RUN_TIME_START = 'allowed_run_time_start'

    ENUM_ALLOWED_RUN_TIME_START = '-allowed_run_time_start'

    ALLOWED_RUN_TIME_END = 'allowed_run_time_end'

    ENUM_ALLOWED_RUN_TIME_END = '-allowed_run_time_end'

    LAST_RUN_RESULTS = 'last_run_results'

    ENUM_LAST_RUN_RESULTS = '-last_run_results'
