# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Sort5Enum(object):

    """Implementation of the 'sort5' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_DESCRIPTION: TODO: type description here.
        DESCRIPTION: TODO: type description here.
        ENUM_NAME: TODO: type description here.
        NAME: TODO: type description here.
        ENUM_SITE_ID: TODO: type description here.
        SITE_ID: TODO: type description here.
        ENUM_ID: TODO: type description here.
        ID: TODO: type description here.

    """

    ENUM_DESCRIPTION = '-description'

    DESCRIPTION = 'description'

    ENUM_NAME = '-name'

    NAME = 'name'

    ENUM_SITE_ID = '-site_id'

    SITE_ID = 'site_id'

    ENUM_ID = '-id'

    ID = 'id'
