# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SiteListSlimEnum(object):

    """Implementation of the 'siteListSlimEnum' enum.

    TODO: type enum description here.

    Attributes:
        SITE_LIST_SLIM: TODO: type description here.

    """

    SITE_LIST_SLIM = 'site_list_slim'
