# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Sort3Enum(object):

    """Implementation of the 'sort3' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_NAME: TODO: type description here.
        NAME: TODO: type description here.
        ENUM_TRAINING_MODE: TODO: type description here.
        TRAINING_MODE: TODO: type description here.
        ENUM_VERSION: TODO: type description here.
        VERSION: TODO: type description here.
        ENUM_ID: TODO: type description here.
        ID: TODO: type description here.
        ENUM_LOCATION_LATITUDE: TODO: type description here.
        LOCATION_LATITUDE: TODO: type description here.
        ENUM_LOCATION_LONGITUDE: TODO: type description here.
        LOCATION_LONGITUDE: TODO: type description here.
        ENUM_DESCRIPTION: TODO: type description here.
        DESCRIPTION: TODO: type description here.
        ENUM_SCORE: TODO: type description here.
        SCORE: TODO: type description here.

    """

    ENUM_NAME = '-name'

    NAME = 'name'

    ENUM_TRAINING_MODE = '-training_mode'

    TRAINING_MODE = 'training_mode'

    ENUM_VERSION = '-version'

    VERSION = 'version'

    ENUM_ID = '-id'

    ID = 'id'

    ENUM_LOCATION_LATITUDE = '-location_latitude'

    LOCATION_LATITUDE = 'location_latitude'

    ENUM_LOCATION_LONGITUDE = '-location_longitude'

    LOCATION_LONGITUDE = 'location_longitude'

    ENUM_DESCRIPTION = '-description'

    DESCRIPTION = 'description'

    ENUM_SCORE = '-score'

    SCORE = 'score'
