# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ContentTypeEnum(object):

    """Implementation of the 'Content-Type' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_APPLICATIONJSON: TODO: type description here.

    """

    ENUM_APPLICATIONJSON = 'application/json'
