# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SortEnum(object):

    """Implementation of the 'sort' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_SITE: TODO: type description here.
        SITE: TODO: type description here.
        ENUM_ID: TODO: type description here.
        ID: TODO: type description here.
        ENUM_SITE_ID: TODO: type description here.
        SITE_ID: TODO: type description here.
        ENUM_DATA: TODO: type description here.
        DATA: TODO: type description here.
        ENUM_DESCRIPTION: TODO: type description here.
        DESCRIPTION: TODO: type description here.
        ENUM_TYPE: TODO: type description here.
        TYPE: TODO: type description here.
        ENUM_CATEGORY: TODO: type description here.
        CATEGORY: TODO: type description here.
        ENUM_SEVERITY: TODO: type description here.
        SEVERITY: TODO: type description here.
        ENUM_TIMESTAMP: TODO: type description here.
        TIMESTAMP: TODO: type description here.
        ENUM_RELEVANT: TODO: type description here.
        RELEVANT: TODO: type description here.
        ENUM_RESOLVED: TODO: type description here.
        RESOLVED: TODO: type description here.
        ENUM_RESOLUTION: TODO: type description here.
        RESOLUTION: TODO: type description here.
        ENUM_PROTOCOL: TODO: type description here.
        PROTOCOL: TODO: type description here.
        ENUM_SCORE: TODO: type description here.
        SCORE: TODO: type description here.
        ENUM_IS_QUALIFIED: TODO: type description here.
        IS_QUALIFIED: TODO: type description here.
        ENUM_NETWORK_ID: TODO: type description here.
        NETWORK_ID: TODO: type description here.
        ENUM_RESOLVED_ID: TODO: type description here.
        RESOLVED_ID: TODO: type description here.
        ENUM_ASSIGNED_ID: TODO: type description here.
        ASSIGNED_ID: TODO: type description here.
        ENUM_STORY_ID: TODO: type description here.
        STORY_ID: TODO: type description here.

    """

    ENUM_SITE = '-site'

    SITE = 'site'

    ENUM_ID = '-id'

    ID = 'id'

    ENUM_SITE_ID = '-site_id'

    SITE_ID = 'site_id'

    ENUM_DATA = '-data'

    DATA = 'data'

    ENUM_DESCRIPTION = '-description'

    DESCRIPTION = 'description'

    ENUM_TYPE = '-type'

    ENUM_TYPE = 'type'

    ENUM_CATEGORY = '-category'

    CATEGORY = 'category'

    ENUM_SEVERITY = '-severity'

    SEVERITY = 'severity'

    ENUM_TIMESTAMP = '-timestamp'

    TIMESTAMP = 'timestamp'

    ENUM_RELEVANT = '-relevant'

    RELEVANT = 'relevant'

    ENUM_RESOLVED = '-resolved'

    RESOLVED = 'resolved'

    ENUM_RESOLUTION = '-resolution'

    RESOLUTION = 'resolution'

    ENUM_PROTOCOL = '-protocol'

    PROTOCOL = 'protocol'

    ENUM_SCORE = '-score'

    SCORE = 'score'

    ENUM_IS_QUALIFIED = '-is_qualified'

    IS_QUALIFIED = 'is_qualified'

    ENUM_NETWORK_ID = '-network_id'

    NETWORK_ID = 'network_id'

    ENUM_RESOLVED_ID = '-resolved_id'

    RESOLVED_ID = 'resolved_id'

    ENUM_ASSIGNED_ID = '-assigned_id'

    ASSIGNED_ID = 'assigned_id'

    ENUM_STORY_ID = '-story_id'

    STORY_ID = 'story_id'
