# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StatusEnum(object):

    """Implementation of the 'Status' enum.

    TODO: type enum description here.

    Attributes:
        GREEN: TODO: type description here.
        RED: TODO: type description here.

    """

    GREEN = 'green'

    RED = 'red'
