# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Sort4Enum(object):

    """Implementation of the 'sort4' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_ID: TODO: type description here.
        ID: TODO: type description here.
        ENUM_SITE_ID: TODO: type description here.
        SITE_ID: TODO: type description here.
        ENUM_TYPE: TODO: type description here.
        TYPE: TODO: type description here.
        ENUM_TIMESTAMP: TODO: type description here.
        TIMESTAMP: TODO: type description here.
        ENUM_USER_ID: TODO: type description here.
        USER_ID: TODO: type description here.

    """

    ENUM_ID = '-id'

    ID = 'id'

    ENUM_SITE_ID = '-site_id'

    SITE_ID = 'site_id'

    ENUM_TYPE = '-type'

    ENUM_TYPE = 'type'

    ENUM_TIMESTAMP = '-timestamp'

    TIMESTAMP = 'timestamp'

    ENUM_USER_ID = '-user_id'

    USER_ID = 'user_id'
