# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AlertSeverityEnum(object):

    """Implementation of the 'AlertSeverity' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_NAMELOWVALUE0: TODO: type description here.
        ENUM_NAMEMEDIUMVALUE1: TODO: type description here.
        ENUM_NAMEHIGHVALUE2: TODO: type description here.
        ENUM_NAMECRITICALVALUE3: TODO: type description here.

    """

    ENUM_NAMELOWVALUE0 = '{"name":"Low","value":0}'

    ENUM_NAMEMEDIUMVALUE1 = '{"name":"Medium","value":1}'

    ENUM_NAMEHIGHVALUE2 = '{"name":"High","value":2}'

    ENUM_NAMECRITICALVALUE3 = '{"name":"Critical","value":3}'
