# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class InsightStatusEnum(object):

    """Implementation of the 'InsightStatus' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_NAMEOPENVALUE0: TODO: type description here.
        ENUM_NAMEHIDDENVALUE1: TODO: type description here.
        ENUM_NAMECOMPLETEDVALUE2: TODO: type description here.

    """

    ENUM_NAMEOPENVALUE0 = '{"name":"Open","value":0}'

    ENUM_NAMEHIDDENVALUE1 = '{"name":"Hidden","value":1}'

    ENUM_NAMECOMPLETEDVALUE2 = '{"name":"Completed","value":2}'
