# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SpecialHintExactEnum(object):

    """Implementation of the 'special_hint__exact' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_0: TODO: type description here.
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.

    """

    ENUM_0 = 0

    ENUM_1 = 1

    ENUM_2 = 2

    ENUM_3 = 3

    ENUM_4 = 4
