# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StatusExactEnum(object):

    """Implementation of the 'status__exact' enum.

    TODO: type enum description here.

    Attributes:
        EOTALERT: TODO: type description here.
        EOTOPERATION: TODO: type description here.
        EALERT: TODO: type description here.
        ENOTRISKY: TODO: type description here.

    """

    EOTALERT = 'eOtAlert'

    EOTOPERATION = 'eOtOperation'

    EALERT = 'eAlert'

    ENOTRISKY = 'eNotRisky'
