# -*- coding: utf-8 -*-

"""
ctddocumentation

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SpecialHintEnum(object):

    """Implementation of the 'SpecialHint' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_NAMEUNICASTVALUE0: TODO: type description here.
        ENUM_NAMEBROADCASTVALUE1: TODO: type description here.
        ENUM_NAMEMULTICASTVALUE2: TODO: type description here.
        ENUM_NAMEMITM VIRTUALVALUE3: TODO: type description here.
        ENUM_NAMEEXTERNALVALUE4: TODO: type description here.

    """

    ENUM_NAMEUNICASTVALUE0 = '{"name":"Unicast","value":0}'

    ENUM_NAMEBROADCASTVALUE1 = '{"name":"Broadcast","value":1}'

    ENUM_NAMEMULTICASTVALUE2 = '{"name":"Multicast","value":2}'

    ENUM_NAMEMITM_VIRTUALVALUE3 = '{"name":"Mitm Virtual","value":3}'

    ENUM_NAMEEXTERNALVALUE4 = '{"name":"External","value":4}'
